@@ -506,18 +506,15 @@ set_notification_text(GtkWindow *nw, const char *summary, const char *body)
 	gtk_label_set_markup(GTK_LABEL(windata->summary_label), str);
 	g_free(str);
 
-	if (strstr(body, "&amp;") || strstr(body, "&lt;") || strstr(body, "&gt;") || strstr(body, "&apos;") || strstr(body, "&quot;"))
+	if (pango_parse_markup (body, -1, 0, NULL, NULL, NULL, NULL))
 	{
 		str = g_strdup_printf("<span color=\"#EAEAEA\">%s</span>", body);
+		gtk_label_set_markup (GTK_LABEL (windata->body_label), str);
+		g_free(str);
 	}
-	else
-	{
-		quoted = g_markup_escape_text(body, -1);
-		str = g_strdup_printf("<span color=\"#EAEAEA\">%s</span>", quoted);
-		g_free(quoted);
+	else {
+		gtk_label_set_text (GTK_LABEL (windata->body_label), body);
 	}
-	gtk_label_set_markup (GTK_LABEL (windata->body_label), str);
-	g_free(str);
 
 	if (body == NULL || *body == '\0')
 		gtk_widget_hide(windata->body_label);
